@@ -24,6 +24,22 @@ class MySQLClient:
     def close(self):
         self.db.close()
 
+    def html_escape(self, value: str):
+        '''
+        对传输的值进行html编码
+        :param value 需要转换的字符串
+        :return 编码后的字符串
+        '''
+        return html.escape(value)
+
+    def html_unescape(self, value: str):
+        '''
+        对传输的值进行html解码
+        :param value 需要转换的字符串
+        :return 解码后的字符串
+        '''
+        return html.unescape(value)
+
     def insert(self, table: str, data: dict, close: bool = True):
         '''
         插入数据
@@ -39,7 +55,7 @@ class MySQLClient:
         row = []
         for d in data.keys():
             col.append(d)
-            row.append('"'+html.escape(data[d])+'"')
+            row.append('"'+self.html_escape(data[d])+'"')
         sql = 'INSERT INTO %s (%s) VALUES (%s)' % (
             table,
             ','.join(col),
@@ -66,7 +82,7 @@ class MySQLClient:
         :param table 表名
         :param query 查询条件
         :param close 是否自动关闭数据库连接，默认True
-        :return {tuple}
+        :return {tuple} 如果没有查询结果，则返回None
         '''
         sql = 'SELECT %s FROM %s WHERE %s' % (
             ','.join(fields),
@@ -83,6 +99,8 @@ class MySQLClient:
         # 关闭数据库连接
         if close:
             self.close()
+        if len(results) == 0:
+            return None
         return results
 
     def update(self, table: str, set: str, query: str, close: bool = True):
