@@ -4,6 +4,7 @@ import hashlib
 import binascii
 import os
 import json
+import re
 from pymoran.timetool import TimeClass
 
 
@@ -98,22 +99,23 @@ class StrClass:
         result = result.replace('/', '')
         return result
 
-    # def symbol_replace(self,val):
+    # def symbol_replace(self,value):
     #     '''
     #     替换文本中的特殊字符
-    #     :param val {str} 需要替换的字符串
+    #     :param value {str} 需要替换的字符串
     #     :return {str} 替换后的字符串
     #     '''
-    #     val=val.replace('\'','&#39;')
-    #     val=val.replace('´','&#180;')
-    #     val=val.replace('`','&#96;')
-    #     return val
+    #     value=value.replace('\'','&#39;')
+    #     value=value.replace('´','&#180;')
+    #     value=value.replace('`','&#96;')
+    #     return value
+
 
 class JsonClass:
     def __init__(self):
         pass
 
-    def jsonToDumps(self, data:dict):
+    def jsonToDumps(self, data: dict):
         '''
         将字典类型数据转换成str
         :param data 字典类型数据
@@ -121,7 +123,7 @@ class JsonClass:
         '''
         return json.dumps(data)
 
-    def jsonToLoads(self, jsonstr:str):
+    def jsonToLoads(self, jsonstr: str):
         '''
         将json字符串数据转换成字典类型
         :param jsonstr json字符串
@@ -157,5 +159,100 @@ class JsonClass:
     #     return result
 
 
+class RegularClass:
+    def __init__(self):
+        pass
+
+    def pInt(self, value: str, include_zero: bool = True):
+        '''
+        正整数
+        :param value 需要验证的字符串
+        :param include_zero 是否包含0，默认True，包含
+        :return {bool} 验证结果，True/False
+        '''
+        value = str(value)
+        result = ''
+        if include_zero:
+            result = re.match(r'^[0-9]+$', value)
+        else:
+            result = re.match(r'^[1-9]\d*$', value)
+        if result:
+            return True
+        return False
+
+    def price(self, value):
+        '''
+        价钱
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(r'^[0-9]+(.[0-9]{2})?$', value)
+        if result:
+            return True
+        return False
+
+    def username(self, value):
+        '''
+        用户名
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(r'^[a-zA-Z0-9_-]{4,20}$', value)
+        if result:
+            return True
+        return False
+
+    def phone(self, value):
+        '''
+        手机号
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(r'^1[3456789]\d{9}$', value)
+        if result:
+            return True
+        return False
+
+    def password(self, value):
+        '''
+        密码
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(r'^[\w!@#$%^&*.]{6,20}$', value)
+        if result:
+            return True
+        return False
+
+    def ipv4(self, value):
+        '''
+        ipv4
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(
+            r'^(((\d{1,2})|(1\d{2})|(2[0-4]\d)|(25[0-5]))\.){3}((\d{1,2})|(1\d{2})|(2[0-4]\d)|(25[0-5]))$',
+            value
+        )
+        if result:
+            return True
+        return False
+
+    def email(self, value):
+        '''
+        email
+        :param value 需要验证的字符串
+        :return {bool} 验证结果，True/False
+        '''
+        result = re.match(
+            r'^[a-zA-Z0-9_-]+@[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+$',
+            value
+        )
+        if result:
+            return True
+        return False
+
+
 if __name__ == '__main__':
-    pass
+    regular = RegularClass()
+    regular.pInt('erwer')
